@@ -15,7 +15,7 @@ import sys
 from datetime import datetime
 from typing import Any, Dict, List
 
-from .literals import ContentClassifier, HumanLoopStatus
+from .literals import ContentClassifierType, HumanLoopStatusType
 
 if sys.version_info >= (3, 8):
     from typing import TypedDict
@@ -39,7 +39,7 @@ _RequiredDescribeHumanLoopResponseTypeDef = TypedDict(
     "_RequiredDescribeHumanLoopResponseTypeDef",
     {
         "CreationTime": datetime,
-        "HumanLoopStatus": HumanLoopStatus,
+        "HumanLoopStatus": HumanLoopStatusType,
         "HumanLoopName": str,
         "HumanLoopArn": str,
         "FlowDefinitionArn": str,
@@ -65,7 +65,7 @@ class DescribeHumanLoopResponseTypeDef(
 HumanLoopDataAttributesTypeDef = TypedDict(
     "HumanLoopDataAttributesTypeDef",
     {
-        "ContentClassifiers": List[ContentClassifier],
+        "ContentClassifiers": List[ContentClassifierType],
     },
 )
 
@@ -88,7 +88,7 @@ HumanLoopSummaryTypeDef = TypedDict(
     "HumanLoopSummaryTypeDef",
     {
         "HumanLoopName": str,
-        "HumanLoopStatus": HumanLoopStatus,
+        "HumanLoopStatus": HumanLoopStatusType,
         "CreationTime": datetime,
         "FailureReason": str,
         "FlowDefinitionArn": str,
